@@ -215,7 +215,7 @@ def get_title(category: str, num: str):
     return f"{category_text} {num}"
 
 
-def preprocess(
+def data_from_folder(
     location: Path,
     law_category: str,
     serial_num: str,
@@ -226,21 +226,32 @@ def preprocess(
 
     Args:
         location (Path): Where the source material is stored
-        law_category (str): Must be either "ra", "eo", "pd", "ca", "bp", "act"
+        law_category (str): Must be either "ra", "eo", "pd", "ca", "bp", "act", "const"
         serial_num (str): A digit-like identifier, e.g. 209, 158-a, etc.
 
     Returns:
         Optional[dict]: Cleaned data dictionary
     """
 
-    folder = get_directory(location, law_category, serial_num)
-    if not folder:
+    if not (folder := get_directory(location, law_category, serial_num)):
         return None
 
-    source = load_statute(folder)
-    if not source:
+    if not (source := load_statute(folder)):
         return None
 
+    return map_to_model(law_category, source)
+
+
+def map_to_model(law_category: str, source: dict) -> Optional[dict]:
+    """The dictionary found in source needs to be mapped to the schema of the database.
+
+    Args:
+        law_category (str): Must be either "ra", "eo", "pd", "ca", "bp", "act", "const"
+        source (dict): Pre-processed content
+
+    Returns:
+        Optional[dict]: Segregated data that matches the database schema for Statutes
+    """
     for field in ["numeral", "law_title", "date", "units"]:
         if not source.get(field, None):
             return None
@@ -273,11 +284,11 @@ def get_statute(parent: Path, child: Path, context: str) -> Optional[dict]:
     parts = str(child).split("/")
     num = parts[-1]
     if not num.isdigit():
-        print(f"Not a digit: {child}")
+        print(f"Not a digit: {child}")  # TODO: must be corrected to include
         return None
 
     print(f"Processing {child}")
-    data = preprocess(parent, context, num)
+    data = data_from_folder(parent, context, num)
     if data:
         return data
     else:
